cumulusci.tasks.apex package
============================

Submodules
----------


.. automodule:: cumulusci.tasks.apex.anon
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.apex.batch
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.apex.testrunner
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: cumulusci.tasks.apex
   :members:
   :undoc-members:
   :show-inheritance:
